crikit.cri.tests package — CRIKit2 0.4.3 documentation

# crikit.cri.tests package

## Submodules

## crikit.cri.tests.test_hilbert module

Testing for Hilbert transform method

Using the math relation a^2 / (a^2 + x^2) (Lorentz/Cauchy) has an analytical Hilbert transform: x^2 / (a^2 + x^2)

crikit.cri.tests.test_hilbert.test_hilbert_in_place()

crikit.cri.tests.test_hilbert.test_hilbert_no_pad()

crikit.cri.tests.test_hilbert.test_hilbert_pad()

crikit.cri.tests.test_hilbert.test_hilbert_replace_min_value()

## crikit.cri.tests.test_kk module

Testing for Kramers-Kronig Phase Retrieval Method

Using the math relation a^2 / (a^2 + x^2) (Lorentz/Cauchy) has an analytical Hilbert transform: x^2 / (a^2 + x^2)– and how that plays into the KK

crikit.cri.tests.test_kk.test_kk()

crikit.cri.tests.test_kk.test_kk_no_bg_norm()

crikit.cri.tests.test_kk.test_kk_properties_read()

crikit.cri.tests.test_kk.test_kk_properties_setter()

crikit.cri.tests.test_kk.test_kk_rng()

crikit.cri.tests.test_kk.test_kk_transform()

crikit.cri.tests.test_kk.test_kk_transform_fail()

## crikit.cri.tests.test_kk_alg module

Testing for Kramers-Kronig Phase Retrieval Method

Using the math relation a^2 / (a^2 + x^2) (Lorentz/Cauchy) has an analytical Hilbert transform: x^2 / (a^2 + x^2)– and how that plays into the KK

crikit.cri.tests.test_kk_alg.test_kk()

crikit.cri.tests.test_kk_alg.test_kk_3d()

crikit.cri.tests.test_kk_alg.test_kk_conjugate()

crikit.cri.tests.test_kk_alg.test_kk_no_bg_norm()

## crikit.cri.tests.test_merge_nrbs module

crikit.cri.tests.test_merge_nrbs.test_basic()

## crikit.cri.tests.test_pec module

Testing Phase error correction

crikit.cri.tests.test_pec.test_basic()

crikit.cri.tests.test_pec.test_basic2D()

crikit.cri.tests.test_pec.test_basic3D()

crikit.cri.tests.test_pec.test_fix_ends()

crikit.cri.tests.test_pec.test_fix_rng()

crikit.cri.tests.test_pec.test_rng()

crikit.cri.tests.test_pec.test_rng_redux()

crikit.cri.tests.test_pec.test_rng_redux2D()

crikit.cri.tests.test_pec.test_rng_redux3D()

crikit.cri.tests.test_pec.test_transform_rng()

## crikit.cri.tests.test_sec module

Testing scale error correction

crikit.cri.tests.test_sec.test_basic()

crikit.cri.tests.test_sec.test_basic_transform()

crikit.cri.tests.test_sec.test_rng()

## Module contents